Classes and Objects - the Basics
::::::::::::::::::::::::::::::::

.. toctree::
   :caption: Classes and Objects - the Basics
   :maxdepth: 2

   Objectorientedprogramming.rst
   Achangeofperspective.rst
   ObjectsRevisited.rst
   UserDefinedClasses.rst
   ImprovingourConstructor.rst
   AddingOtherMethodstoourClass.rst
   ObjectsasArgumentsandParameters.rst
   ConvertinganObjecttoaString.rst
   InstancesasReturnValues.rst
   Glossary.rst
   Exercises.rst
